@@ -3,7 +3,7 @@
 ##
 alphaols <- function(z, reg.number = NULL) 
 {
-  if (!(class(z) == "ca.jo")) {
+  if (!inherits(z, "ca.jo")) {
     stop("\nPlease, provide object of class 'ca.jo' as 'z'.\n")
   }
   RKV <- z@RK%*%z@V
