@@ -3,7 +3,7 @@
 ##
 cajools <- function(z, reg.number=NULL)
 {
-  if (!(class(z) == "ca.jo") && !(class(z) == "cajo.test")) {
+  if ((!inherits(z, "ca.jo")) && (!inherits(z, "cajo.test"))) {
     stop("\nPlease, provide object of class 'ca.jo' or 'cajo.test' as 'z'.\n")
   }
   P <- z@P
